---
title: "CSL/Clio"
subtitle: "Guide d'utilisation et de création de styles CSL supportant un formatage complexe des sources primaires"
author: Bastien Dumont
date: 29/12/2020
lang: fr-FR
colorlinks: true
toc: true
lof: true
---

<!-- TODO :
    — REF
    — Mécanisme pour modifier la date à chaque fois que l'on fusionne dans master
-->

# Introduction

Le but du projet *CSL/Clio* est de fournir une solution clé en main aux historiens pour utiliser des gestionnaires bibliographiques basés sur CSL, tels que [*Zotero*](https://www.zotero.org/), et mettre en forme automatiquement les citations et les bibliographies grâce aux processeurs CSL existants. Il comprend trois aspects : 

  * Proposer des stratégies claires pour encoder des références bibliographiques dans le format CSL en contournant ses limitations plutôt qu'en l'étendant ;
  * Fournir des feuilles de style CSL qui poussent le plus loin possible l'automatisation de la mise en forme des citations et de la bibliographie en s'appuyant sur ces stratégies d'encodage ;
  * Fournir des outils de post-traitement (macros pour *LibreOffice*, filtres pour *Pandoc*) pour automatiser la plus grande partie des modifications qui doivent être effectuées sur le résultat produit par les processeurs CSL.
  
La première section développe les principes et les objectifs du projet. Malgré mes efforts, il est possible qu'elle reste quelque peu obscure à la première lecture. Sa lecture est utile, mais pas indispensable à la compréhension des sections suivantes ; il est possible de la parcourir rapidement, puis de revenir éventuellement plus tard, en ayant acquis un peu d'expérience. Les sections suivantes donnent des indications pratiques pour utiliser *Zotero* selon les principes de *CSL/Clio*, utiliser les outils fournis et étendre le nombre de styles proposés. Il est nécessaire, avant de les lire, d'être un minimum familiarisé avec l'interface et les fonctionnalités de base de *Zotero*.

Les outils fournis par *CSL/Clio* peuvent être utilisés soit avec *Pandoc*, soit avec *LibreOffice*, soit les deux combinés. Si vous ne souhaitez pas utiliser l'un de ces deux logiciels, vous pouvez passer les paragraphes qui les concernent spécifiquement. Il est également possible d'utiliser les styles avec *Microsoft Word*, mais le document DOCX obtenu devra ensuite être ouvert dans *LibreOffice* si vous souhaitez utiliser les outils de post-traitement.

<!-- TODO : Vous pouvez adresser vos remarques, questions, requêtes et signalements de bugs... -->

# Principes

## Présentation de CSL

*Citation Style Language* (CSL) est un format de fichier basé sur [XML](https://www.w3.org/standards/xml/core) qui décrit la manière dont doivent être mises en forme des références bibliographiques au sein d'un document. Il permet de mettre en forme différemment une référence selon qu'elle se trouve dans une citation ou dans la bibliographie, et de distinguer entre la première mention d'une référence et ses mentions ultérieures. Pour ce faire, il spécifie :

  * Les différentes variables qui peuvent être utilisées pour décrire une référence dans un gestionnaire de bibliographie : `title`, `author`, `editor`, `issued`, `page`,...
  * La manière dont doivent être rédigées les instructions de mise en forme dans une feuille de style ;
  * La manière dont ces instructions doivent être interprétées par les logiciels qui traitent ces feuilles de style pour procéder à la mise en forme, CSL n'étant pas lui-même un programme mais un format.
  
Les règles que doit respecter tout fichier CSL (variables utilisées, syntaxe,...) sont spécifiées dans un [*schéma*](https://github.com/citation-style-language/schema/tree/v1.0.1), qui est une représentation formelle plutôt destinée à l'ordinateur qu'à un humain. Le contenu du schéma, les contraintes qu'il exprime et la manière dont doivent être interprétées les instructions d'une feuille de style sont explicitées dans les [*spécifications*](http://docs.citationstyles.org/en/1.0.1/specification.html).
  
L'utilisation de CSL pour la mise en forme des citations met en œuvre quatre outils :

  * Un gestionnaire de bibliographie qui se base sur les règles spécifiées par CSL pour décrire les références. Dans la suite de ce document, nous prendrons l'exemple de [*Zotero*](https://www.zotero.org/), mais [d'autres logiciels supportent CSL](https://en.wikipedia.org/wiki/Comparison_of_reference_management_software) ;
  * Une feuille de style conforme à la fois au schéma CSL et aux directives de la revue, de la collection ou de la maison d'édition qui doit publier le travail en train d'être rédigé (les deux principaux dépôts étant [celui du projet CSL](https://github.com/citation-style-language/styles) et [celui de Zotero](https://www.zotero.org/styles)) ;
  * Un processeur CSL, c'est-à-dire un programme qui traite les données enregistrées dans le gestionnaire de bibliographie selon les instructions données dans la feuille de style spécifiée pour produire une référence mise en forme dans un format qui lui est propre ;
  * Un programme qui convertit les données renvoyées par le processeur CSL dans le format du fichier où la référence doit être insérée.
  
De nombreux gestionnaires de bibliographie intègrent un processeur CSL, le plus souvent [*citeproc-js*](https://citeproc-js.readthedocs.io/en/latest/), et proposent des extensions pour les principaux logiciels de traitement de texte. Grâce à ceux-ci, lorsque l'auteur souhaite insérer une citation, il lui suffit de cliquer sur un bouton et d'indiquer dans la fenêtre qui s'ouvre à quels items il veut faire référence et quelles précisions supplémentaires il souhaite apporter ; le plugin appelle le processeur intégré en lui indiquant la feuille de style choisie par l'utilisateur et les informations relatives à la citation et intègre la citation produite par le processeur dans le document courant sous la forme d'une note de bas de page ou d'une référence dans le corps du texte. On en trouvera un exemple [sur le site de *Zotero*](https://www.zotero.org/support/word_processor_integration). [D'autres processeurs existent](https://citationstyles.org/developers/#/csl-processors), notamment celui utilisé par [Pandoc](https://pandoc.org/).

La mise en œuvre de cette chaîne opératoire pour la mise en forme des citations comporte de nombreux avantages sur un travail purement manuel. En automatisant la mise en forme des citations, elle réduit les risques d'incohérences et d'erreurs : on gagne ainsi du temps à la fois lors de la saisie des citations et à la relecture. Elle évite d'avoir à vérifier si une référence a déjà été citée ou non et dans quelle note. La séparation entre le stockage des références bibliographiques et leur mise en forme facilite également l'utilisation des mêmes références dans plusieurs publications soumises à des normes différentes. Elle permet même de changer les règles de mise en forme en cours de rédaction sans perdre de temps à modifier toutes les citations existantes, ce qui peut s'avérer précieux lorsque l'éditeur met à jour ses instructions ou lorsque l'on décide de soumettre à une autre revue que celle envisagée initialement. Certes, il est nécessaire de prendre un peu de temps pour apprendre à utiliser ces outils et pour enregistrer sa bibliographie dans le gestionnaire ; mais cet investissement est faible si l'on se contente d'utiliser ou de modifier légèrement des feuilles de styles existantes, et il est très rapidement rentabilisé.

Enfin, CSL présente toutes les garanties de durabilité. Les spécifications sont publiées sous license [Creative Commons Attribution-ShareAlike](https://creativecommons.org/licenses/by-sa/3.0/), une license [libre](https://www.gnu.org/philosophy/free-sw.html) qui leur garantit une large diffusion. Les processeurs existants, ainsi que plusieurs logiciels de gestion de bibliographie (dont *Zotero*), sont relativement nombreux, dotés pour certains d'une importante communauté d'utilisateurs, en partie dépendants les uns des autres, et libres, ce qui rend très peu probable l'arrêt de leur développement. La large [batterie de tests](https://github.com/citation-style-language/test-suite) maintenue sur le dépôt en ligne de CSL permet aux développeurs de vérifier si le comportement de leur programme est conforme aux spécifications : ainsi, dans la plupart des cas, un style CSL donné produira bien les mêmes résultats quel que soit le processeur utilisé — et si tel n'est pas le cas, il est possible de signaler le problème sur le dépôt du code source du projet. Le principal risque pour l'utilisateur est qu'une modification des spécifications CSL impose de modifier les styles ou l'enregistrement des données dans le gestionnaire de bibliographie ; cependant, dans ce cas, des outils seront très probablement mis à disposition pour rendre la migration automatique, [comme cela a été le cas](https://github.com/citation-style-language/utilities/blob/master/update-styles-0.8.1-to-1.0.sh) lors du passage de la version 0.8 à la version 1.0 des spécifications.

> **Pour aller plus loin :**
>
>  * [Site de CSL](https://citationstyles.org/)
>  * [Introduction à CSL](https://docs.citationstyles.org/en/1.0.1/primer.html)

## Limites actuelles de CSL pour les publications en Histoire

Si CSL a été développé principalement par des chercheurs pour les besoins de la publication scientifique, le fait qu'il soit pensé pour couvrir les besoins de l'ensemble des sciences humaines le rend peu adapté, au premier abord, à certains besoins particuliers.

Pour les historiens, son point faible le plus évident est le manque de support pour la gestion des sources primaires. En effet, CSL prévoit principalement une variable `title`^[
    `Titre` dans *Zotero*.
] pour le titre d'une référence et une variable `container-title`^[
    Dans *Zotero*, `Titre du livre` si l'item enregistré est un chapitre ou `Publication` s'il s'agit d'un article.
],  pour l'ensemble dans lequel elle est insérée (livre pour un chapitre d'ouvrage, revue pour un article), mais rien pour le titre d'une source. Or, on ne peut pas renseigner le titre de la source comme `title` et celui de l'ouvrage dans lequel elle est publiée dans `container-title` car certaines sont publiées dans des articles ou des chapitres d'ouvrages. En outre, selon les éditeurs, il faut indiquer soit le titre de la source, soit celui de la publication, soit les deux : si l'on veut que les enregistrements dans la base de données bibliographique soient complets et indépendants des styles utilisés, une variable *ad hoc* est donc nécessaire. Or, le fait que l'utilisation d'une telle variable soit limitée aux historiens empêche qu'elle soit ajoutée dans les spécifications^[
    Pour plus de détails, voir [cette discussion](https://github.com/citation-style-language/schema/issues/388) sur le dépôt officiel du schéma CSL.
].

Bien que ce point ne soit pas explicité, les spécifications actuelles de CSL (v. 1.0.1) semblent supposer que la localisation d'un passage dans une publication se fait en fonction d'un critère unique, tel que la page, le chapitre ou la ligne. Les processeurs, en accord avec les tests officiels, ne prévoient en tout cas que ce cas de figure^[
    Il semblerait que [*citeproc-js* supporte les cas les plus simples de localisations selon plusieurs critères](https://forums.zotero.org/discussion/comment/350840). Toutefois, je n'ai pas réussi à le vérifier.
]. Or, le plus souvent, lorsque l'on précise la ligne, on indique aussi la page, le folio ou la colonne. De même, on peut avoir besoin de citer une source à la fois selon les divisions internes de la source (p. ex. VI, 5) et selon la page dans l'édition. De ce fait, dans les boîtes de dialogue d'ajout de citation, on ne peut renseigner qu'un des deux critères de localisation dans le champ approprié, l'autre étant à ajouter en suffixe (voir [@fig:double-locator-zotero]). Cela pose problème à double titre : d'abord parce que certains localisateurs, dans certains styles, sont rendus différemment selon qu'ils sont seuls ou combinés à d'autres^[
    Comparer p. ex. « La Fontaine, *À Fouquet*, l. 7 » (ligne seule) et « La Fontaine, *Le Songe de Vaux*, p. 26^5^ » (page et ligne en exposant). Voir aussi [cette discussion](https://github.com/citation-style-language/schema/issues/342).
] ; ensuite parce que cette lacune oblige à mettre en forme une partie des localisateurs directement dans le champ *Suffixe*, ce qui peut poser problème en cas de modification des normes suivies. Par ailleurs, CSL prévoit une grande variété de critères de localisation dans les *citations*, mais pas dans les *références bilbiographiques* : ainsi, on peut se référerer à un folio précis d'un manuscrit dans une citation, mais non indiquer la localisation d'une œuvre dans un manuscrit dans la bibliographie.

![Localisation selon la page et la ligne dans la fenêtre classique d'ajout de citation de *Zotero*](double-locator-zotero.png){#fig:double-locator-zotero}

Concernant les titres de revues, les spécifications CSL prévoient une variable `container-title-short` qui permet d'indiquer une forme abrégée. *Zotero* [propose en outre une option](https://www.zotero.org/support/kb/journal_abbreviations) pour ignorer cette variable et utiliser à la place la liste d'abréviations de l'*Index Medicus*. Toutefois, ces deux approches ne sont pas satisfaisantes, d'une part parce qu'elles ne prévoient pas un mécanisme semblable pour les titres de collections, d'autre part parce que les listes d'abréviations varient selon les éditeurs et les revues. Pour l'instant, seul *Pandoc* permet de fournir une liste d'abréviations en plus du fichier CSL [en utilisant un mécanisme généralisable à toutes les variables](https://pandoc.org/MANUAL.html#specifying-a-citation-style) (dont `collection-title`). Cependant, il faut acquérir des connaissances de bases sur le format JSON et CSL pour constituer une telle liste, et les utilisateurs de logiciels de traitement de texte tels que *Word* ou *LibreOffice* ne peuvent pas en bénéficier. *Zotero* devrait aussi acquérir cette fonctionnalité dans le futur^[
    En réalité, [une solution existe déjà](https://forums.zotero.org/discussion/comment/155854/#Comment_155854) mais elle n'est pas officiellement documentée et est assez délicate à metre en œuvre. Nous l'expliquons néanmoins [plus loin](#listes-dabréviations).
].

Enfin, il manque des solutions claires pour l'encodage de certains éléments. Il n'existe pas, dans CSL, de types de documents tels que « actes de colloque », « répertoire », « blog » ou « site Web ». Il n'est pas prévu non plus de rôle pour les collaborateurs^[
    Il existe bien un champ *Collaborateur* dans *Zotero*, mais il n'est relié à aucune variable dans CSL.
]. Comme nous l'avons évoqué plus haut, il n'est pas possible de localiser autrement une partie d'ouvrage dans la bibliographie que par pages, volume ou partie : il n'est donc pas possible d'indiquer à quels folios ou dans quelles colonnes de la *Patrologie grecque* se trouve une source (bien que ce soit possible dans les citations). 

Heureusement, les membres du projet CSL sont parfaitement conscients de ces limites que les nombreux retours d'utilisateurs mettent en évidence, et ils travaillent à faire évoluer les spécifications pour y apporter des réponses. À l'heure à laquelle ce guide est rédigé, les spécifications officielles, qui sont implémentées par les processeurs, portent le numéro de version 1.0.1. Elles devraient bientôt évoluer vers la version 1.0.2, qui introduira quelques nouveautés sans véritablement résoudre les problèmes que nous avons identifiés. À plus long terme, CSL sera plus profondément remanié dans la version 1.1. Les discussions en cours sont très prometteuses, mais nul ne sait quand elles aboutiront, et il faudra encore un délai supplémentaire pour que les processeurs soient mis à jour. En attendant, il nous faut trouver des moyens de surmonter les limites actuelles de CSL en faisant avec l'existant.

> **En savoir plus sur l'évolution de CSL :**
>
>  * Le blog de CSL contient un [article très synthétique sur les évolutions envisagées](https://citationstyles.org/2020/07/11/seeking-public-comment-on-CSL-1-0-2/) ;
>  * Sur la version 1.0.2, en gardant à l'esprit qu'il s'agit encore d'un travail en cours, quoique très avancé, on peut prendre connaissance des [spécifications](https://github.com/citation-style-language/documentation/blob/master/specification.rst). Un document synthétique listant les évolutions par rapport à la version 1.0.1 est disponible [ici](https://docs.google.com/document/d/1wY1cOOamDYYh8VNW7h_uleqieBDGOa_LYsRiVdQy1RI/) ;
>  * Sur la version 1.1, on peut consulter la [liste des problèmes identifiés ou en cours de traitement](https://github.com/citation-style-language/schema/milestone/1) ;
>  * À plus long terme encore, [quelques objectifs ont été identifiés pour une version 1.2](https://github.com/citation-style-language/schema/labels/1.2) ;
>  * Voir aussi la [liste des propositions pour de futures versions de CSL](https://github.com/orgs/citation-style-language/projects/3) (toutes versions confondues).

## Objectifs de *CSL/Clio*

Actuellement, pour bénéficier malgré tout des avantages de CSL, chacun doit définir des stratégies d'encodage *ad hoc* et créer des styles qui reposent sur elles en fonction de ses besoins. Cela requiert beaucoup de recherches et de temps pour comprendre comment fonctionne CSL, découvrir des fonctionnalités peu connues de *Zotero*, programmer des outils et corriger ensuite ses erreurs. Pour des raisons fort compréhensibles, peu de chercheurs ont le temps ou l'envie de se consacrer à ces tâches. Le but du projet *CSL/Clio* est de réduire le plus possible l'investissement requis en fournissant des solutions clés en main pour utiliser CSL et automatiser le plus possible le travail de post-traitement qui reste nécessaire. Ainsi, le temps d'apprentissage nécessaire pour maîtriser les principes et les outils présentés dans ce guide sera largement compensé par le temps et l'énergie gagnés lors du processus de rédaction. De plus, ce travail pourra servir de base pour coordonner les efforts des individus qui souhaiteront apporter des améliorations ou de nouvelles fonctionnalités, au lieu que chacun perde son temps en partant de zéro. Les lignes directrices du projet sont exposées maintenant, avant de passer à la pratique.

### Fournir des stratégies d'encodage communes

On peut surmonter de trois manières différentes le fait que les spécifications CSL et les gestionnaires de bibliographie ne déterminent pas de stratégies d'encodage claire pour une partie des besoins relatifs à la discipline historique :

  #. N'utiliser que les fonctionnalités offertes, en modifiant et en complétant à la main le résultat produit par le processeur CSL. Ainsi, pour indiquer une source, on peut enregistrer la publication dans laquelle elle est éditée dans *Zotero*, choisir un style assez proche de celui de la revue visée et ajouter à la main la mention de l'auteur et du nom de la source. Cette solution n'implique aucun bricolage, limite au minimum le temps d'apprentissage et laisse aux revues la possibilité de proposer des styles CSL sur les dépôts officiels qui ne sont pas complètement conformes à leurs directives, mais suivent en revanche rigoureusement les spécifications de CSL. Elle ne permet toutefois pas de tirer pleinement profit des possibilités de CSL et impose un long temps de vérification et de correction ;
  #. Inventer des variables qui ne figurent pas dans les spécifications CSL et rédiger des feuilles de style qui les utilisent. Cette solution est applicable dans la mesure où le processeur utilisé supporte les variables non standard, ce qui est le cas de *citeproc-js* (le plus répandu) et de *citeproc* (sur lequel s'appuie Pandoc)^[Le logiciel [*Juris-M*](https://juris-m.github.io/), basé sur *Zotero*, fait un usage important de cette possibilité et utilise même des extensions à la syntaxe de CSL qui sont implémentées dans *citeproc-js*. Il offre des fonctionnalités intéressantes, mais [celles qui pourraient être utilisées pour les références aux sources primaires](https://forums.zotero.org/discussion/81644/classical-sources-numbers-and-pages) ne résolvent pas tous les problèmes et risquent d'en poser pour la mise en forme de la bibliographie. En outre, CSL-M ne comble pas toutes les lacunes de CSL pour les historiens et n'est compatible qu'avec *citeproc-js*.] ;
  #. Utiliser des variables existantes d'une manière qui n'est pas prévue par les spécifications, ce qui permet de respecter formellement le schéma CSL et de créer des styles compatibles avec tous les processeurs. Plus précisément, cette stratégie consiste à *spécialiser* des variables très abstraites (telles que `annote` pour indiquer un titre de source) et à *détourner* des variables plus spécialisées dont les historiens n'ont a priori pas besoin (telles que `original-publisher` pour indiquer la langue d'origine d'un document traduit).
  
Le projet *CSL/Clio* repose sur la troisième option. Certes, l'invention de nouvelles variables présente l'avantage de la clarté, et le détournement de variables existantes pourrait entrer en conflit avec des besoins imprévus. J'ai choisi de privilégier la compatibilité avec le plus grand nombre de processeurs. De plus, l'utilisation de variables non standard interdirait de placer les styles développés dans le cadre de *CSL/Clio* dans les dépôts de CSL et de *Zotero*. J'espère que les évolutions futures de CSL permettront de se passer du détournement de variables ; si les adaptations nécessaires à notre discipline se limitent à des spécialisations, une intégration aux dépôts officiels deviendra envisageable.

Ces règles sont exposées dans la partie [*Gérer ses données bibliographiques avec* Zotero](#gérer-ses-données-bibliographiques-avec-zotero).

### Créer un ensemble de styles cohérent et interopérables

Le premier objectif de *CSL/Clio* est donc de fournir des règles communes pour encoder des bibliographies selon les catégories prévues par CSL, en définissant quelles variables peuvent être spécialisées ou détournées pour quels types d'information. Ce vocabulaire commun constitue une condition préalable à la création de styles interopérables, c'est-à-dire qui puissent tous être utilisés avec une base de données bibliographique qui suit ces règles. Une autre condition est l'existence de règles communes pour structurer les styles. L'idée principale est de diviser le code en *modules*, c'est-à-dire de petites unités, de manière à ce que l'on puisse facilement comprendre comment il est organisé et créer un autre style en le modifiant. 

Considérons, par exemple, la structure non modulaire suivante (écrite en pseudo-code et non en XML) :

~~~
Pour toute citation, réaliser les étapes suivantes 
en séparant les segments par des virgules :
— Afficher le nom de l'auteur avec le prénom abrégé 
  avant le nom en petites capitales ;
— Afficher le titre en italiques s'il s'agit d'un 
  livre, en caractères droits avec des guillemets 
  s'ils s'agit d'un article ;
— Afficher la maison d'édition en caractères droits 
  s'il s'agit d'un livre, la nom de la revue en 
  italiques s'il s'agit d'un article.
~~~

Si l'on veut modifier un seul aspect (p. ex. retirer les guillemets d'un titre d'article), il faut parcourir tout le code pour trouver le passage concerné ; or, les règles des revues en histoire sont souvent beaucoup plus raffinées que cela. Le code modulaire suivant sera beaucoup plus facile à comprendre et à manier à mesure qu'il se complexifiera :

~~~
Pour toute citation, réaliser les étapes suivantes 
en séparant les segments par des virgules :
— Appliquer la macro "nom de l'auteur" ;
— Appliquer la macro "titre" ;
— Appliquer la macro "publication".

Macro "nom de l'auteur" :
— Afficher le nom de l'auteur avec le prénom abrégé 
  avant le nom en petites capitales.

Macro "titre" :
— Afficher le titre en italiques s'il s'agit d'un 
  livre, en caractères droits avec des guillemets 
  s'il s'agit d'un article.

Macro "publication" :
— Afficher la maison d'édition en caractères droits 
  s'il s'agit d'un livre, la nom de la revue en 
  italiques s'il s'agit d'un article.
~~~

Si l'on reprend l'exemple précédent, on saura immédiatement qu'il faut modifier la macro "titre" pour supprimer les guillemets, et ce d'autant plus s'il est convenu que tous les styles doivent indiquer la mise en forme du titre principal du document (et seulement cela) dans un macro appelée "titre".

Pour garantir que les styles produise bien la mise en forme attendue, ils sont contrôlés automatiquement après chaque modification. D'une part, *CSL/Clio* intrègre une bibliographie type d'une cinquantaine d'items représentant chacun une configuration différente. D'autre part, chaque style est associé à un fichier qui indique la mise en forme attendue par la revue ou l'éditeur pour chacun de ces items dans différentes situations (première citation, citation ultérieure, en combinaison,...). Un style ne sera pas mis en ligne tant qu'il ne produira pas un rendu conforme, et il ne sera pas modifié si la modification proposée entraîne des effets indésirables.

Les conventions suivies dans *CSL/Clio* sont exposées dans la partie [*Programmer de nouveaux styles*](#programmer-de-nouveaux-styles). Contrairement aux règles d'enregistrement des données bibliographiques, il n'est pas nécessaires de les connaître si l'on ne souhaite pas en programmer soi-même de feuille de style CSL. Cependant, il est bon d'avoir conscience que les styles mis à disposition par le projet *CSL/Clio* suivent des stratégies précises qui ne sont pas suivies par ceux des dépôts officiels. Le lecteur sera également rassuré de savoir que les conventions suivies permettent de produire des styles fiables et que l'on peut aisément corriger ou modifier pour produire d'autres styles.

### Coupler CSL avec des outils de post-traitement

Quelles que soient les stratégies utilisées, certaines exigences d'éditeurs et de revues ne peuvent pas être satisfaites en se limitant à CSL. Pour ne citer qu'un exemple, il est impossible, dans la bibliographie, d'introduire les références aux folios par « f. » s'il n'y en a qu'un et « ff. » s'il y en a plusieurs. Pour cette raison, *CSL/Clio* fournit deux types d'outils de post-traitement qui permettent de limiter le plus possible le travail manuel requis pour corriger les imperfections de la mise en forme automatique : des [filtres Lua](https://pandoc.org/lua-filters.html) (encore peu nombreux) à utiliser avec *Pandoc* et des macros pour *LibreOffice Writer*. Pour l'instant, je n'ai pas prévu de réécrire les macros pour en faire une version utilisable avec *Microsoft Word* ; heureusement, la suite *LibreOffice* est gratuite et peut très bien traiter des documents au format DOCX rédigés sous *Word*. Chaque style est fourni avec un document qui précise ses limites et indique quelles macros utiliser et quelles tâches doivent être accomplies manuellement.

Les informations sur les outils de post-traitement figurent dans la partie [*Automatiser la mise en forme*](#automatiser-la-mise-en-forme).

### Un projet évolutif et ouvert aux retours des utilisateurs

Pour l'instant, le projet *CSL/Clio* est surtout informé par ma pratique de doctorant en histoire du Proche-Orient médiéval. Il est possible que je n'aie pas rencontré les mêmes problèmes que vous, que je n'aie pas eu les mêmes besoins. Si, par exemple, vous trouvez un bug dans les outils proposés, si certains passages de ce guide ne vous paraissent pas clair, si vous avez besoin d'un style de revue qui n'est pas fourni, si les outils de post-traitement n'effectuent pas une tâche dont vous avez besoin, ou si vous souhaitez participer, vous pouvez :

  * Écrire à la liste mail du projet : <!-- REF --> ;
  * [Ouvrir un ticket](<!-- REF -->) sur le dépôt du projet (plus spécifiquement pour les bugs ou les demandes de fonctionnalités supplémentaires).

# Gérer ses données bibliographiques avec *Zotero*

Pour pouvoir utiliser les styles de *CSL/Clio*, il est tout d'abord primordial de bien enregistrer sa bibliographie dans son gestionnaire. Dans cette partie, nous allons tout d'abord indiquer quelques fonctionnalités auxquelles nous ferons référence par la suite, puis nous allons indiquer les conventions utilisées par *CSL/Clio* pour l'enregistrement des données bibliographiques. Comme le reste de ce manuel, cette section prend l'exemple de *Zotero* parce que c'est le logiciel que j'utilise. Si vous utilisez un autre logiciel et que vous constatiez des différences, n'hésitez pas à me les signaler : je me ferai un plaisir de les indiquer dans ce guide.

## Utilisation avancée de *Zotero*

Parmi les fonctionnalités de *Zotero* que nous allons passer en revue, seules les trois premières sont indispensables. 

### Indications de mise en forme dans une valeur de champ

Il est possible de mettre certaines parties des valeurs que vous renseignez dans les champs en italiques, gras, petites capitales, indice ou exposant. C'est utile, notamment, lorsqu'un titre cite un autre titre, comme dans la [@fig:titre-dans-titre] (noter que, dans ce cas, si le titre principal était en italiques, *Dialogica polymorpha antiiudaica* serait en caractères droits).

![Utilisations de balises pour mettre en valeur un titre cité dans un autre titre](titre-dans-titre.png){#fig:titre-dans-titre}

Vous trouverez plus d'informations [ici](https://citationstyles.org/authors/#/rich-text-within-fields). Bien que cette fonctionnalité ne fasse pas partie des spécifications CSL, elle est supportée par de nombreux processeurs, avec quelques variantes : voir pour [*citeproc*](https://pandoc.org/MANUAL.html#specifying-bibliographic-data) (utilisé par *Pandoc*) et [*citeproc-js*](https://www.zotero.org/support/fr/kb/rich_text_bibliography) (utilisé par *Zotero* et d'autres gestionnaires de bibliographie).

### Champ *Extra*

L'interface de *Zotero* contient un champ *Extra* dans lequel l'utilisateur peut renseigner des variables qui ne sont pas prévues dans les champs proposés par défaut pour le type de document sélectionné. La syntaxe utilisée est *variable: valeur*, chaque variable étant séparée de la précédente par un passage à la ligne. Une valeur peut contenir des espaces. Pour citer un individu, il faut séparer son nom de son prénom par deux barres verticales (Altgr+6 sur un clavier AZERTY). Si une variable contient plusieurs valeurs (par exemple `editor`), il faut un enregistrement complet par valeur. *Le nom de la variable est celui prévu dans les [spécifications CSL](https://docs.citationstyles.org/en/1.0.1/specification.html#appendix-iv-variables), pas celui affiché dans l'interface de* Zotero *!*

Exemples :

> annote: Titre de la source\
> editor: Nom || Prénom\
> ~~annote: "Titre de la source"~~\
> ~~Éditeur: Nom || Prénom~~
> ~~Éditeur: Nom || Prénom, Autrenom || Autreprénom~~

### Intervalles de dates

Le champ *Date* ne supporte pas les intervalles tels que « 2009–2011 ». Lorsque vous entrez plusieurs nombres séparés par des tirets, *Zotero* les interprète comme des indications de jour, mois et année. Pour indiquer un intervalle de date dans *Zotero*, vous devez laisser le champ *Date* vide et renseigner la date dans le champ *Extra* comme valeur de la variable `issued` en utilisant la syntaxe *année-mois-jour/année-mois-jour*, où *mois* et *jour* sont optionnels et où les deux dates doivent compter le même nombre d'éléments.

Exemples :

> issued: 1999-09/1999-12\
> issued: 1999-09/2000-01\
> issued: 1999/2000\
> ~~issued: 1999-09/12~~\
> ~~issued: 1999-09/2000~~

### Console JavaScript

Une console JavaScript est accessible dans l'interface de *Zotero* via le menu *Outils > Développeur > Run JavaScript*. Elle permet d'automatiser certaines tâches laborieuses dans la gestion de la base de données bibliographique, et peut être utile si vous avez besoin de modifier de manière systématique l'enregistrement de certaines informations pour utiliser les styles de *CSL/Clio*. À titre d'exemple, il fut un temps où j'enregistrais les titres de sources dans le champ *Résumé* ; lorsque j'ai dû les transférer de la variable `abstract` (correspondant au champ *Résumé*) à la variable `annote` (à enregistrer dans *Extra*), j'ai pu le faire en utilisant le code suivant (les lignes commençant par `//` sont des commentaires que j'ai ajoutés pour expliquer le déroulement de l'algorithme) :

~~~ {.javascript}
// Récupérer la collection sélectionnée dans l'interface.
var collection = ZoteroPane.getSelectedCollection();
// Récupérer les notices dans la collection.
var items = collection.getChildItems();
// Pour chaque notice...
for (let item of items) {
  // Récupérer la valeur du champ Résumé.
  let sourceName = item.getField('abstractNote')
  // Passer directement à la notice suivante si cette
  // valeur est nulle.
  if (!sourceName) continue
  // Si cette valeur est renseignée, récupérer la
  // valeur du champ Extra.
  let extraField = item.getField('extra')
  // Ajouter à cette valeur un passage à la ligne (\n),
  // puis "annote: ", puis la valeur de Résumé.
  item.setField('extra', extraField + '\nannote: ' + sourceName)
  // Vider le champ Résumé.
  item.setField('abstractNote', '')
  // Sauvegarder le résultat.
  item.saveTx()
}
~~~

On pourra trouver sur [le site d'apprentissage de la Fondation Mozilla](https://developer.mozilla.org/fr/docs/Apprendre/JavaScript) des ressources sur JavaScript (seules les connaissances les plus basiques sont requises). Le [site de *Zotero*](https://www.zotero.org/support/dev/client_coding/javascript_api) contient une introduction et de nombreux exemples. N'hésitez pas à [demander de l'aide](#demander-de-laide-et-signaler-des-bugs) !

Attention : avant d'utiliser la console, faites une sauvegarde de votre répertoire de données, dont l'emplacement peut être trouvé via le menu *Édition > Préférences > Avancées > Fichiers et dossiers*. Les modifications ne sont pas réversibles ! Après avoir appliqué vos modifications, il peut être judicieux de cliquer sur *Vérifier l'intégrité de la base de données* dans le même menu.

### Export d'une collection en format CSL JSON

*Zotero* permet également, par un simple clic droit, d'exporter une collection dans le format de votre choix. Vous pouvez ainsi exporter une collection dans un fichier texte, opérer des modifications automatiques et réimporter le fichier obtenu dans *Zotero*. Dans ce cas, le format CSL JSON est à préférer car il est facile à comprendre et utilise les variables de CSL. Notez toutefois que vous perdrez vos notes, marqueurs et fichiers attachés si vous procédez ainsi.

<!-- TODO : référence à correct-json si ça peut être utile, mais il n'est plus nécessaire pour Pandoc -->

### Listes d'abréviations

CSL ne propose qu'un mécanisme rudimentaire pour les abréviations : la variable `container-title-short`. D'une part, cette variable n'est pas prévue pour les collections ; d'autre part, son utilité est diminué par le fait que les revues et les éditeurs divergent quant aux abréviations à utiliser. *Pandoc* et *Zotero* fournissent tous deux un mécanisme pour abréger automatiquement les titres selon une liste fournie par l'utilisateur. Dans les deux cas, il faut fournir un [fichier JSON](https://www.json.org/json-fr.html) présentant la structure suivante :

~~~
{ 
    "default": {
        "nom-de-la-variable-a-abreger": {
            "Titre long": "Abrev",
            "Titre long 2": "Abrev2"
        },
        "nom-autre-variable": {
            "Titre long 3": "Abrev3"
        }
    }
}
~~~

[Pour *Pandoc*](https://pandoc.org/MANUAL.html#specifying-a-citation-style), son utilisation est assez simple : il suffit de reprendre cette structure, d'indiquer les noms de revues ou de collections telles qu'elles apparaissent dans la base de données et d'utiliser l'option `--citation-abbreviations` ou la métadonnées `citation-abbreviations` pour indiquer au programme où se trouve le fichier d'abréviations à utiliser lors de son invocation. Sachant que les noms de revues sont représentés par la variable `container-title`, un fichier court mais complet pourrait ressembler à :

~~~
{ 
    "default": {
        "container-title": {
            "Revue de l'histoire religieuse": "RHR",
            "Jerusalem Studies in Arabic and Islam": "JSAI"
        },
        "collection-title": {
            "Sources chrétiennes": "SC"
        }
    }
}
~~~

Pour *Zotero*, le cas est plus complexe. Il faut en effet transformer les titres complets selon les règles suivantes :

  * Passer toutes les capitales en minuscules ;
  * Supprimer les mots suivants : and et y und la le the l' d' ;
  * Supprimer les caractères suivants : ! " # $ % & ' ( * )  + , . / : ; < = > ? @ [ \ ] ^ _ ` { | } ~ ;
  * Lorsque plusieurs espaces se suivent, n'en conserver qu'un.
  
En outre, il faut placer en début de document l'objet suivant :

~~~
"info": {
    "URI": "http://www.zotero.org/abbreviations/nom.json",
    "name": "Nom du fichier d'abréviations"
}
~~~

Si l'on reprend l'exemple précédent, cela donne :

~~~
{
    "info": {
        "URI": "http://www.zotero.org/abbreviations/nom.json",
        "name": "Nom du fichier d'abréviations"
    },
    "default": {
        "container-title": {
            "revue de histoire religieuse": "RHR",
            "jerusalem studies in arabic islam": "JSAI"
        },
        "collection-title": {
            "sources chrétiennes": "SC"
        }
    }
}
~~~

Pour que le fichier soit pris en compte, il doit être enregistré obligatoirement sous le nom *abbreviations.json* à la racine de votre répertoire de données, dont l'emplacement peut être trouvé via le menu *Édition > Préférences > Avancées > Fichiers et dossiers*. Il faut donc conserver l'ensemble des fichiers d'abréviations avec chacun son titre dans un répertoire distinct ou dans le même répertoire et copier celui que vous voulez utiliser en donnant ce nom à la copie. À la suite de cette opération, *Zotero* doit être redémarré s'il est ouvert pour que le changement de fichier soit pris en compte. Enfin, dans votre logiciel de traitement de texte, il faut ouvrir les préférences de l'extension *Zotero* et cocher la case *Utiliser les abréviations MEDLINE des titres de revues* (voir [@fig:preferences-medline]) ; si cette option n'apparaît pas, c'est que le style n'utilise pas les formes abrégées.

Quoique je n'aie pas testé d'autres possibilités, d'autres variables peuvent être abrégées, par exemple l'éditeur (variable `publisher`). Si les abréviations que vous avez prévues ne fonctionnent pas, vérifiez que le style CSL que vous utilisez prévoit l'utilisation des formes abrégés (p. ex. `<text variable="container-title" form="short"/>`) : si ce n'est pas le cas, vous pouvez demander de l'aide en fonction de la provenance du style, soit à [*CSL/Clio*](#un-projet-évolutif-et-ouvert-aux-retours-des-utilisateurs), soit à [*Zotero*](#demander-de-laide-et-signaler-des-bugs).

![Préférences du document dans l'extension *Zotero* pour *LibreOffice*](preferences-medline.png){#fig:preferences-medline}

### Demander de l'aide et signaler des bugs

Si vous rencontrez un problème qui concerne *Zotero* et non *CSL/Clio*, vous pouvez tout d'abord consulter la [documentation](https://www.zotero.org/support/) et la [FAQ](https://www.zotero.org/support/kb), puis faire une recherche sur le [forum](https://forums.zotero.org/discussions). Si vous ne trouvez toujours pas de solution, [cette page](https://www.zotero.org/support/getting_help) vous indiquera comment demander de l'aide et [celle-ci](https://www.zotero.org/support/styles#reporting_style_errors) comment signaler des erreurs dans les styles *hébergés par* Zotero.

Si votre problème concerne *CSL/Clio* (enregistrement d'un ouvrage, défaut dans un style fourni par *CSL/Clio*, macro,...), voir [ici](#un-projet-évolutif-et-ouvert-aux-retours-des-utilisateurs).

## Enregistrement des documents selon les conventions de *CSL/Clio*

Cette section passe en revue les stratégies d'encodage propres à *CSL/Clio*. Pour plus de clarté, vous pouvez vous référer à la [collection de test](<!--REF-->) du projet, que vous pouvez importer dans *Zotero*.

### Rôles

L'indication des rôles pose généralement peu de problèmes. Le cas des sources primaires mis à part, vous devez seulement respecter trois règles :

  * Un éditeur d'ouvrage collectif doit être indiqué comme *Éditeur* (voir cependant ci-dessous pour le cas d'une source publiée dans un ouvrage collectif) ;
  * Un collaborateur doit être désigné comme *Directeur de collection* : en effet, CSL ne prévoit pas de variable `collaborator`, aussi le champ *Collaborateur* de *Zotero* n'est-il pas pris en compte par les processeurs ;
  * Si une notice relative à un article contenu dans un ensemble plus vaste porte la mention d'un collaborateur, celui-ci est toujours considéré comme ayant collaboré à la rédaction du document sur lequel porte la notice, non de l'ensemble dans lequel il est publié. Par exemple, l'enregistrement reproduit dans la [@fig:collaborateur-avec-container] est rendu ainsi selon les normes de la *Revue des études byzantines* : 
  
> P. [Andrist]{.smallcaps}, avec la collaboration de V. [Déroche]{.smallcaps}, Questions ouvertes autour des *Dialogica polymorpha antiiudaica*, dans C. [Zuckermann]{.smallcaps} (éd.), *Constructing the Seventh Century* (TM 17), Paris 2013, p. 9‑26.

![Enregistrement d'un article écrit en collaboration dans *Zotero*](collaborateur-avec-container.png){#fig:collaborateur-avec-container}


### Sources primaires

Le type d'une source primaire est celui de la publication qui la contient. Les informations relatives à cette publication sont enregistrées normalement, à l'exception des points suivants :

  * L'auteur de la publication est indiqué comme éditeur ou traducteur ; pour certains types, comme *Thèse*, cette information doit être enregistrée dans *Extra* ;
  * Le champ *Auteur* doit être réservé à l'auteur de la source ;
  * Si la source est publiée dans un chapitre d'ouvrage collectif, l'éditeur du livre doit être renseigné dans le champ *Auteur du livre* ;
  * Si la source est publiée dans une compilation d'articles d'un ou plusieurs auteurs sans qu'il n'y ait d'éditeur, les auteurs du livre doivent être enregistrés dans *Extra* avec la variable `container-author` (voir [@fig:enregistrement-doctrina-jacobi]) ;
  * *Titre abrégé* est interprété comme le titre abrégé de la source, non de la publication.
  
Les informations suivantes peuvent être ajoutées :

  * Le titre de la source doit être renseigné dans *Extra* comme valeur de la variable `annote` ;
  * Si le titre de la source et celui de la publication sont redondants, utilisez la variable `year-suffix` dans *Extra* avec une valeur telle que « titre redondant ». Selon le style utilisé, cela conduira à afficher seulement l'un des deux titres dans la bibliographie. (*N.-B. : La variable `year-suffix` doit être réservée à cet usage.*) ;
  * Indiquer les noms de répertoires dans *Extra* avec la variable `references` (par exemple : `references: CPG 1536`). La référence entrée sera affichée telle quelle dans la bibliographie : s'il vous faut une espace insécable entre le nom du répertoire et le numéro, il espace doit être insécable dans votre enregistrement. Notez que CSL permet seulement d'afficher ou non cette variable, mais non de choisir entre plusieurs valeurs.
  
Les champs *Éditeur* et *Traducteur* ne sont pas disponibles pour certains types de documents dans l'interface de *Zotero*. Quand vous enregistrez, par exemple, une source publiée dans une thèse, vous devez renseigner les variables `editor` et `translator` dans *Extra*.
  
Si vous avez besoin de vous référer à la publication en tant que telle (par exemple pour citer l'introduction de l'éditeur), enregistrez une notice distincte qui ne contient pas la référence à la source éditée et où l'éditeur est enregistré comme auteur.
  
![Enregistrement de la *Doctrina Jacobi* dans *Zotero*](enregistrement-doctrina-jacobi.png){#fig:enregistrement-doctrina-jacobi}

### Manuscrits

Pour un manuscrit, renseigner :

  * Le nom de la ville de conservation dans *Lieu* ;
  * La bibliothèque dans *Archive* ;
  * Le dépôt dans *Localisation dans l'archive* ;
  * Le numéro dans *Cote* ; 
  * L'identifiant dans un répertoire (comme Diktyon) dans *Extra* comme valeur de la variable `source` ;
  * La forme abrégée de la référence au manuscrit dans *Extra* comme valeur de la variable `container-title-short`. 
  
Cette stratégie d'encodage laisse libres les variables `annote` et le champ *Titre abrégé* pour un éventuel nom de source. Le champ *Titre* peut être utilisé librement (par exemple pour afficher la référence au manuscrit dans le panneau central de *Zotero*) car il n'est pas utilisé pour la mise en forme des citations.

Tous les éditeurs ne suivent pas les mêmes conventions pour désigner les manuscrits. Il est donc possible que vous deviez rédiger plusieurs notices pour un même manuscrit si vous les citez dans des publications soumises à des normes différentes.

![Enregistrement d'un manuscrit selon les normes de la REB](mss-reb.png){#fig:mss-reb} 

![Notice d'une source inédite](mss-source.png){#fig:mss-source}

### Mémoires et thèses

Dans le type *Thèse*, indiquer la nature du mémoire dans *Type* (Thèse de doctorat, PhD dissertation, Mémoire de Master,...).

### Actes de colloque, revues, sites webs, blogs

CSL prévoit des types pour des publications dans des actes de colloques, des revues, ou sur des sites webs et des blogs, mais pas pour les contenants eux-mêmes, sauf dans le cas d'un ouvrage collectif qui peut être renseigné comme un livre avec un éditeur. Si vous souhaitez enregistrer un document relevant d'un de ces types non fournis, vous pouvez créer une notice avec le type de contenu correspondant (*Article de colloque*, *Article de revue*,...) et ne renseigner que les informations qui concernent le contenant, comme dans la [@fig:actes-colloque]. Vous pouvez en outre assigner au document un titre abrégé en utilisant la variable *Titre abrégé*. L'inconvénient est qu'aucun titre n'apparaîtra dans le panneau central de *Zotero*.

Plus spécifiquement, pour les actes de colloque, vous pouvez indiquer comme valeur de la variable `scale` la suite de caractères à introduire entre le titre des actes et l'intitulé du colloque pour les styles qui les placent l'un à la suite de l'autre. Si cette suite de caractères commence ou finit par une espace, comme dans la [@fig:actes-colloque], elle doit être enclose dans des [balises](#indications-de-mise-en-forme-dans-une-valeur-de-champ) pour que l'espace ne soit pas supprimée automatiquement par *Zotero*. En règle générale, il est préférable d'utiliser à cet effet la balise `<span style="font-variant:small-caps">...</span>`, qui ne modifie pas le rendu visuel dans la mesure où les caractères qu'elle encadrent ne disposent pas d'une version en petites capitales.

![Enregistrement d'actes de colloque dans *Zotero*](actes-colloque.png){#fig:actes-colloque}

### Documents traduits

Pour des traductions de la littérature secondaire, on indiquera le nom du traducteur dans *Traductueur*, la langue accompagnée de la préposition dans *Extra* comme valeur de `original-publisher` et le titre d'origine comme valeur de `original-title`.

![Ouvrage traduit de l'anglais dans *Zotero*](litt-sec-traduite.png)

### Documents dont le titre est traduit

Il est parfois d'usage de traduire les titres de documents écrits dans certaines langues en bibliographie. Dans ce cas, vous pouvez indiquer la langue comme valeur de la variable `jurisdiction` dans *Extra*, par exemple pour qu'elle soit affichée entre parenthèses à la suite du titre traduit.

Exemple :

> jurisdiction: hébreu

### Ouvrages en plusieurs volumes

Trois cas de figure sont à envisager :

  * Pour citer l'ouvrage entier, il suffit d'indiquer le nombre de volumes dans le champ dédié. Les styles qui le prévoient indiqueront ainsi le nombre de volumes. Si la publication est échelonnée sur plusieurs années, voir [comment indiquer un intervalle d'années](#intervalles-de-dates) ;
  * Pour citer un volume de l'ouvrage qui ne porte pas lui-même un titre spécifique, il faut enregistrer le titre du livre dans *Titre* et le numéro de volume dans *Volume* (voir [@fig:volume-sans-titre-particulier]). Dans ce cas, à moins que vous ne souhaitiez indiquer l'année précise de publication du volume cité dans le cas d'un ouvrage paru en plusieurs fois, vous pouvez aussi utiliser la notice de l'ouvrage entier et indiquer le volume comme localisateur au moment de l'ajout de la citation, comme dans la [@fig:citation-volume] ;
  * Pour citer un volume qui porte son propre titre, indiquer le titre du volume dans *Titre*, le numéro de volume dans *Volume* et le titre du livre entier dans un champ `container-title` à ajouter dans *Extra* (voir [@fig:volume-avec-titre-particulier]).
  
![Volume sans titre particulier dans *Zotero*](volume-sans-titre-particulier.png){#fig:volume-sans-titre-particulier}

![Volume indiqué dans la fenêtre classique d'ajout de citation de *Zotero* (mise en forme selon les normes de la REB)](citation-volume.png){#fig:citation-volume}

![Volume avec un titre particulier dans *Zotero*](volume-avec-titre-particulier.png){#fig:volume-avec-titre-particulier}

### Patrologie

Les sources publiées dans la *Patrologie grecque*, la *Patrologie latine* et la *Patrologie orientale* doivent être enregistrées dans le type *Article de revue* : 

  * Il est possible de renseigner le titre de la source à la fois comme valeur de la variable `annote` et dans le champ *Titre* de manière à ce qu'il s'affiche dans le panneau central de *Zotero* ; dans ce cas, il faut utiliser la variable `year-suffix` comme expliqué [à propos des sources primaires](#sources-primaires) ; 
  * Le titre de la collection doit être renseigné dans *Publication* et le volume dans *Volume* ;
  * Les numéros de colonnes doivent être renseignés comme la valeur de la variable `chapter-number`.

### Apostrophes et guillemets

Là où vous utilisez les caractères « droits » ASCII (i. e. \" et \'), les processeurs `citeproc-js` et `citeproc` choisissent automatiquement les guillemets typographiques correspondant à la langue dans laquelle vous écrivez (en français, « ou » et ') ; de même si vous utilisez les guillemets droits pour indiquer une citation à l'intérieur d'une citation (*\"il dit \'courir\', je dis \'marcher\'\"* → « il dit “courir”, je dis “marcher” »). Il convient de prendre garde à deux points :

 * Si vous utilisez une [liste d'abréviations](#listes-dabréviations), veillez bien à ce que les titres abrégés soient bien écrits avec des apostrophes ASCII et non des apostrophes typographiques, sans quoi ils risquent de ne pas être reconnus ;
 * Dans les titres écrits en langues étrangères, si vous souhaitez que la typographie d'origine soit respectée, vous devez utiliser les caractères correspondants : par exemple *“Semper Vagus”: The Anatomy of a Mobile Monk* et non *\"Semper Vagus\": The Anatomy of a Mobile Monk*, qui serait rendu dans un article en français « Semper Vagus »: The Anatomy of a Mobile Monk. (Le champ *Langue* pourrait permettre, dans un futur plus ou moins lointain, de différencier la mise en forme en fonction de la langue de rédaction de l'ouvrage comme dans [Juris-M](<!-- REF -->), une version de *Zotero* étendue pour les besoins des juristes.)

### Numéros en chiffres romains

Les numéros en chiffres romains (notamment les pages dans les introductions) doivent être écrits en minuscules dans le champ *Pages* ou la valeur de `chapter-number` : ils seront rendus, suivant les styles, par des petites capitales ou des majuscules. 

Dans le gestionnaire de bibliographie, les numéros de volume doivent toujours être enregistrés en chiffres arabes : selon les styles, ils seront rendus en chiffres arabes ou romains.

### Classement de la bibliographie en catégories

Les styles *CSL/Clio* classent la bibliographie par catégories : d'abord les sources, puis la littérature secondaire. Lorsque le style le requiert, des regroupements supplémentaires peuvent être opérés : par exemple, le style de la *Revue des études byzantines* crée automatiquement une liste des manuscrits cités. Pour ajouter des critères de classement supplémentaires, vous pouvez utiliser la variable `keyword` dans *Extra*. Vous pouvez même créer des sous-catégories en ajoutant les mots-clefs de rang inférieur à la suite des mots-clefs de rang supérieur.

Exemples :

> keyword: grec\
> keyword: géorgien\
> keyword: grec papyrus\
> keyword: grec chronique\
> keyword: monastères économie

Les entrées seront regroupées en sections selon les mots-clefs associés et placées dans l'ordre alphabétique ; il vous appartiendra ensuite d'insérer les titres correspondants et, éventuellement, de les réordonner. Comme pour toute modification manuelle, vous devez auparavant vous assurer que vous n'aurez plus besoin de modifier les citations mises en forme automatiquement.

## Pratiques à éviter

J'ai tenté de lister ici quelques pratiques qui peuvent être tentantes, mais s'avèrent finalement contre-productives. Je me suis en grande partie inspiré de mon expérience : n'hésitez pas à me faire part de vos malheurs pour enrichir cette section !

### Faire confiance à l'enregistrement automatique des références

*Zotero* propose [différents outils](https://www.zotero.org/support/adding_items_to_zotero) qui permettent d'enregistrer automatiquement des références dans le gestionnaire de bibliographie. Outre les modifications requises par *CSL/Clio*, il convient d'être attentif aux points suivants :

  * Si une valeur est renseignée dans le champ *URL*, elle risque d'être utilisée par certains styles : ne la laissez que si vous souhaitez ce comportement ;
  * Si vous laissez l'URL, supprimez l'indication de proxy de votre institution ;
  * Vérifiez que les noms soient renseignés sous la forme la plus généralement acceptée et de manière cohérente au sein de votre base de données : les notices d'autorité [de la Bibliothèque nationale de France](https://data.bnf.fr/) ou de la [Bibliothèque du Congrès](https://authorities.loc.gov) vous permettent de savoir quelles sont les formes attestées et quelle est la forme standard du nom de nombreux auteurs ;
  * Dans les catalogues de bibliothèques, les titres sont souvent renseignés selon une syntaxe uniforme (titre et sous-titre séparés par deux points, [guillemets](#apostrophes-et-guillemets),...) : vous aurez peut-être besoin de les retoucher pour restituer leur typographie originelle ;
  * Vérifiez qu'il n'y ait pas de renseignements manquants.

### Mettre en forme les informations en fonction d'un style donné

Lorsque l'on renseigne une notice bibliographique, on peut être tenté de ne pas renseigner certaines informations ou de les mettre au format de la revue ou de l'éditeur auquel on compte soumettre son manuscrit. Cette pratique va à l'encontre du principe de séparation entre les données bibliographiques et leur mise en forme et peut poser des problèmes soit si vous citez le document avec un style que vous n'aviez pas prévu à l'origine, soit même avec le style que vous aviez prévu.

De manière générale, à l'exception de l'URL quand elle renvoie au portail sur lequel vous avez téléchargé un article, soyez le plus complet possible : cela vous évitera de devoir reprendre toute votre bibliographie pour ajouter des informations que vous ne pensiez pas utiles. Dans le même ordre d'idées, n'abrégez pas de références : vous pourrez définir des [listes d'abréviations](#listes-dabréviations) ou utiliser des [macros](#macros) adaptées à chaque style, voire à chacun de vos écrits. N'hésitez pas non plus à renseigner des dates complètes (par exemple avec l'indication de mois pour une revue qui paraît plusieurs fois par an) : CSL permet de définir pour chaque style les parties de la date qui doivent être affichées.

Plus particulièrement, n'abrégez pas les prénoms. Même vous pensez devoir toujours les présenter sous une forme abrégée dans votre manuscrit, il est important qu'ils soient renseignés sous leur forme pleine dans le gestionnaire de bibliographie. D'une part, cela permet au processeur d'afficher une forme plus complète du prénom lorsque deux auteurs cités partagent le même nom et les mêmes initiales. D'autre part, si vous renseignez le même auteur tantôt avec un prénom abrégé, tantôt avec le prénom complet, et que vous citiez deux notices portant des formes différentes, le processeur considérera les deux entrées comme désignant des individus distincts partageant les mêmes initiales et activera le mécanisme de désambiguïsation.

# Automatiser la mise en forme

## Installation

### Fichiers CSL

<!-- Pour les articles qui ne sont pas écrits en français, il faut modifier le fichier CSL en modifiant la valeur de la variable "default-locale" et celle des termes dans la section "locale". -->

### Filtres

### Macros

## Utilisation des extensions *Zotero* pour logiciels de traitement de texte

### Ajout d'une citation

Contrairement au champ *Volume*, par exemple, dans la base de données bibliographique, les valeurs que vous entrez dans la fenêtre d'ajout de citation pour la localisation du passage cité (volume, page, ligne, folio,...) ne sont pas traitées comme des nombres, mais comme du texte. Par conséquent, si vous souhaitez qu'un numéro de volume, de pages ou autre soit indiqué en chiffres romains, il faut le renseigner dans les caractères de bas de casse latins correspondants ; si vous souhaitez qu'il soit affiché comme un chiffre arabe, en utilisant les chiffres arabes correspondants.\
**Attention :** En principe, le processeur doit rendre les chiffres romains en minuscules, majuscules ou petites capitales en fonction des instructions données dans la feuille de style. Cependant, si vous utilisez `citeproc-js` (p. ex. avec *Zotero*), vous devez entrer les chiffres romains en majuscules si vous souhaitez qu'ils soient rendus ainsi, comme dans la [@fig:citation-volume]. Il s'agit d'un bug qui a été signalé.<!-- TODO : suivre, modifier la figure quand le bug sera résolu --> En revanche, la mise en forme des minuscules en petites capitales fonctionne.

Lorsque vous utilisez plusieurs critères pour localiser un passage (par exemple la page et la ligne), seul le premier critère peut entrer dans le champ dédié : l'autre doit être mis en forme directement dans le suffixe de la citation (voir [@fig:double-locator-zotero]). De plus, si vous voulez utiliser les macros ou les filtres de post-traitement, les numéros de pages avec lignes doivent être séparés par un trait d'union *encadré d'espaces* : les macros ou les filtres se chargeront d'opérer la bonne mise en forme. 

Dans le cas où l'on cite un repère de texte au sein d'une page ou d'une colonne (par exemple pour la *Patrologie grecque*), on peut indiquer la page (ou la colonne) dans le champ en sélectionnant l'étiquette appropriée, puis renseigner le bloc (A-D) ou la ligne comme une ligne dans *Suffixe* (i. e. précédé de « , l. »). La macro de chaque style s'occupera de la mise en forme. 

Exemples (on indique en gras le nom de chacun des champs de la fenêtre classique d'ajout de citation dans *Zotero*) :
  
> **Item sélectionné :** Dialogue **Page :** 5 **Suffixe :** , l. 4-5\
> **Item sélectionné :** Dialogue **Page :** 5-6\
> **Item sélectionné :** Dialogue **Page :** 5 **Suffixe :** , l. 4 - p. 6, l. 12\
> **Item sélectionné :** PG 14 **Colonne :** 1208 **Suffixe :** , l. A5-B3\
> **Item sélectionné :** PG 14 **Colonne :** 1208 **Suffixe :** , l. A-B\
> **Item sélectionné :** PG 14 **Colonne :** 1208 **Suffixe :** , l. A - 1211, l. C
  
Pour indiquer une localisation en fonction des divisions internes d'une source en plus de la localisation dans la publication, on doit indiquer la localisation selon les divisions internes dans le champ *Section* et mettre la pagination en suffixe comme dans la [@fig:citation-source-section].\
**Attention :** Lorsque l'étiquette « section » est utilisée pour la localisation avec un ouvrage contenant une source primaire (i. e. où la variable `annote` est utilisée), les styles de *CSL/Clio* l'identifient comme faisant référence aux divisions internes de la source et la placent à l'endroit indiqué par les directives de la revue ou de l'éditeur. Si vous voulez vraiment renvoyer à une section dans un tel ouvrage, utilisez le champ *Suffixe*.

![Localisation selon les divisions internes d'une source dans la fenêtre classique d'ajout de citation de l'extension *Zotero* pour *LibreOffice* (mise en forme selon les normes de la REB)](citation-source-section.png){#fig:citation-source-section}

Enfin, pour assurer le plus de souplesse possible, les styles *CSL/Clio* ne prévoient pas d'insérer automatiquement des délimiteurs entre les différentes parties d'une citation : vous devez donc déterminer vous-même la manière dont elles s'articulent entre elles en utilisant les champs *Préfixe* et *Suffixe*, comme dans la [@fig:sources-multiples].

![Sources multiples dans la fenêtre classique d'ajout de citation](sources-multiples.png){#fig:sources-multiples}

### Mise en forme de la bibliographie

<!-- À aborder :
    — Mise en forme automatique spéciale pour certains styles (abréviations REB avec | )
    — Possibilité de supprimer certaines références
    — référence à #classement-de-la-bibliographie-en-catégories
-->

## Utilisation des outils de post-traitement

### Filtres

### Macros

# Programmer de nouveaux styles

## Ressources fournies par le projet CSL

## Directives spécifiques à *CSL/Clio*
